@@ -8,14 +8,12 @@ class DataFilterRadioButtons(ControlPlugin):
     A plugin for filtering data to be displayed by removing records where a certain column's value does not equal the
     selected radio button value.
     Inputs:
-        html_id = unique name for this component
-        parent_id = html_id of the parent object holding this plugin
         header = header text/object
         control_type = must be either 'plot_control', 'data_control', or 'sidebar_control' depending on where it appears
         data_col = column from data to check for values matching button
         data_values = list of possible values to populate the radio button list
     """
-    def __init__(self, html_id, parent_id, header, control_type, data_col, data_values):
+    def __init__(self, header, control_type, data_col, data_values):
         self.data_col = data_col
         component = dcc.RadioItems
         component_inputs = {
@@ -28,8 +26,6 @@ class DataFilterRadioButtons(ControlPlugin):
         }
 
         super().__init__(
-            html_id=html_id,
-            parent_id=parent_id,
             header=header,
             control_type=control_type,
             component=component,
